@@ -7,6 +7,8 @@ use Any::Moose; with qw/
 use MRO::Compat;
 use File::Spec;
 
+has no_capture => (is => 'rw');
+
 has '_path' => (
   is       => 'rw',
   isa      => 'Str',
@@ -25,6 +27,7 @@ has '_cmd' => (
   init_arg   => 'cmd',
   builder    => '_build__cmd',
   handles    => [qw(
+    git
     add branch checkout commit config diff fetch init log move 
     push pull rebase reset remove show status tag
   )],
@@ -37,6 +40,7 @@ sub _build__cmd {
     die_on_error => $self->_die_on_error,
     verbose      => $self->is_verbose,
     cwd          => $self->_path,
+    no_capture   => $self->no_capture,
   );
 }
 
@@ -67,10 +71,18 @@ Git::Class::Worktree
   $work->add('.');
   $work->commit;
 
+  $work->git('ls-files'); # can run an arbitrary command
+
 =head1 DESCRIPTION
 
 This is another (experimental) interface to C<git> executable for convenience. Note that this will change the current directory to the path you specify when you create an object, and as of 0.03, it'll take you back to the previous current directory when you demolish the object.
 
+=head1 METHODS
+
+=head2 no_capture
+
+is an accessor/mutator to determine if we should use Capture::Tiny to capture the output of git commands. If your web apps hang because of the capturing, set this to true to disable it.
+
 =head1 INTERNAL METHODS
 
 =head2 BUILDARGS
