@@ -10,7 +10,7 @@ use Cwd;
 
 my $CMD;
 my $CWD = Cwd::cwd;
-my $GIT_DIR = dir(tempdir(CLEANUP => 1));
+my $GIT_DIR = dir(tempdir(CLEANUP => 1))->resolve;
 
 local $ENV{GIT_CLASS_TRACE} = 1;
 
@@ -26,18 +26,24 @@ sub initialize {
   $class->skip_this_class('git is not available') unless $CMD->is_available;
 }
 
-sub test00_init : Tests(2) {
+sub test00_init : Tests(4) {
   my $class = shift;
 
+  is dir(Cwd::cwd()) => $GIT_DIR, $class->message("current directory is correct");
+
   my $got = $CMD->git('init');
 
   ok $got, $class->message("initialized local repository");
   ok !$CMD->_error, $class->message('and no error');
+
+  ok $GIT_DIR->subdir('.git')->exists, $class->message('.git exists');
 }
 
 sub test01_add : Tests(2) {
   my $class = shift;
 
+  $class->skip_this_test('not in a local repository') unless $GIT_DIR->subdir('.git')->exists;
+
   my $file = $GIT_DIR->file('README');
   $file->save('readme');
   ok $file->exists, $class->message("created README file");
@@ -50,7 +56,9 @@ sub test01_add : Tests(2) {
 sub test02_commit : Tests(2) {
   my $class = shift;
 
-  my $got = $CMD->git('commit', { message => 'committed README' });
+  $class->skip_this_test('not in a local repository') unless $GIT_DIR->subdir('.git')->exists;
+
+  my $got = $CMD->git('commit', { message => 'committed README', author => 'A U Thor <author@example.com>' });
 
   ok $got, $class->message("committed to the local repository");
   ok !$CMD->_error, $class->message('and no error');
